require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_zonesite',
  dscmeta_resource_friendly_name: 'ZoneSite',
  dscmeta_resource_name: 'SimonW_ZoneSite',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'InternetSettings',
  dscmeta_module_version: '1.1.0',
  docs: 'The DSC ZoneSite resource type.
         Automatically generated from version 1.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_zone: {
      type: "Enum['MyComputer', 'LocalIntranet', 'TrustedSite', 'Internet', 'Restricted']",
      desc: 'Specifies Zone',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_type: {
      type: "Enum['*', 'file', 'ftp', 'http', 'https', 'knownfolder', 'ldap', 'news', 'nntp', 'oecmd', 'shell', 'snews']",
      desc: 'Sets protocol to be added, use * for any',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_platform: {
      type: "Optional[Enum['x86', 'x64', 'All']]",
      desc: 'Add for 32-bit, 64-bit or All applications',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Absent', 'Present']]",
      desc: 'Sets Uri to be Present or Absent on machine',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_uri: {
      type: 'String',
      desc: 'Address to configure, i.e. site.domain.com',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
